@@ -17,74 +17,66 @@
 #include "dirs_list.h"
 #include "esvn_utils.h"
 
-bool C_DirsList::load(const C_Path& path, QListView* list_dirs, QListViewItem* root, bool open, bool disable_symlinks, bool append) 
+bool C_DirsList::load(const C_Path& path, QListView* list_dirs, C_DirViewItem* root, bool open, bool disable_symlinks, bool append) 
 {
 
-	C_DirViewItem* root_item = 0;
+//  if (!path.FullPath().isEmpty()) {
+//      QFileInfo fi(path.FullPath());
+//          if(!fi.exists() ) 
+//              return false;
+//  }
 
-	if (!path.FullPath().isEmpty()) {
-		QFileInfo fi(path.FullPath());
-			if(!fi.exists() ) 
-				return false;
+    //disable colors
+    svn_status_ = NULL;
+
+    if (!root)  {//wihtout parent it means top-level directory
+        if (!append) 
+            list_dirs->clear();
+
+		root = new C_DirViewItem(list_dirs);
+
+		//root_item->setPixmap(0, QPixmap::fromMimeSource( "folder_home_2.png" ) );
+		root->setPixmap(0, QPixmap::fromMimeSource("folder_green_open.png")); //colorscm.png") );
+
+		root->SetName(path.Name());
+		root->SetPath(path.Path());
+
+		load(path, list_dirs, root);
+		//root->setOpen(TRUE);
+		return true;
 	}
 
-	//disable colors
-	svn_status_ = NULL;
-
-	if (!root)  {//wihtout parent it means top-level directory
-		if (!append) 
-			list_dirs->clear();
-
-		if (root == NULL) {
-            root_item = new C_DirViewItem(list_dirs);
-
-			//root_item->setPixmap(0, QPixmap::fromMimeSource( "folder_home_2.png" ) );
-			root_item->setPixmap(0, QPixmap::fromMimeSource("folder_green_open.png")); //colorscm.png") );
-
-            root_item->SetName(path.Name());
-            root_item->SetPath(path.Path());
-
-			load(path, list_dirs, root_item);
-			//root_item->setOpen(TRUE);
-			return true;
-		}
-
-	}
-
-	C_SvnEntries svn_entries(svn_dir_);
-	//cout << "path:" << path << endl;
-	svn_entries.setDir(path, true); //force "show dirs"
+    C_SvnEntries svn_entries(svn_dir_);
+    //cout << "path:" << path << endl;
+    svn_entries.setDir(path, true); //force "show dirs"
 
 
-	//performs open/close and change folder icon
-	if (root) { //if parent defined, 
-		if (root->childCount() >0 && root->firstChild()->text(EsvnLVI::ITEM_WORKING_DIRECTORY) != "empty item") {
-			C_SvnFile svn_file_info = svn_entries.get(root->text(EsvnLVI::ITEM_FULL_PATH));
-			root->setPixmap(0,getIcon(root->text(EsvnLVI::ITEM_FULL_PATH), root->isOpen(), &svn_file_info) );
-			return true;
-		}
-
+    //performs open/close and change folder icon
+	if (root->childCount() >0 && root->firstChild()->text(EsvnLVI::ITEM_WORKING_DIRECTORY) != "empty item") {
+		C_SvnFile svn_file_info = svn_entries.get(root->FullPath());
+		root->setPixmap(0,getIcon(root->FullPath(), root->isOpen(), &svn_file_info) );
+		return true;
 	}
 
 
-	if (root->childCount() == 1 && root->firstChild()->text(EsvnLVI::ITEM_WORKING_DIRECTORY) == "empty item")
-		root->takeItem(root->firstChild());
+    if (root->childCount() == 1 && root->firstChild()->text(EsvnLVI::ITEM_WORKING_DIRECTORY) == "empty item")
+        root->takeItem(root->firstChild());
 
-	QDir workspace_dir = (root == NULL) ? QDir(path.FullPath()) : QDir(root->text(EsvnLVI::ITEM_FULL_PATH));
-	workspace_dir.setFilter(QDir::Dirs | QDir::Hidden | (disable_symlinks ? QDir::NoSymLinks : 0) );
+    QDir workspace_dir = QDir(root->FullPath());
+    workspace_dir.setFilter(QDir::Dirs | QDir::Hidden | (disable_symlinks ? QDir::NoSymLinks : 0) );
 
-	if (!workspace_dir.exists() ) {
-		qWarning( ("Cannot find " + path.FullPath()).local8Bit());
-		return false;
-	}
+    if (!workspace_dir.exists() ) {
+        qWarning( ("Cannot find " + path.FullPath()).local8Bit());
+        return false;
+    }
 
-	for (size_t i=0; i<workspace_dir.count(); i++) {
+    for (size_t i=0; i<workspace_dir.count(); i++) {
 
-		QString curr = workspace_dir[i];
-		if ( curr == "." || curr == ".." || curr == svn_dir_)
-			continue;
+        QString curr = workspace_dir[i];
+        if ( curr == "." || curr == ".." || curr == svn_dir_)
+            continue;
 
-		C_SvnFile svn_file_info = svn_entries.get(curr);
+        C_SvnFile svn_file_info = svn_entries.get(curr);
 
         C_DirViewItem *item;
         C_DirPath full_path;
@@ -92,90 +84,84 @@ bool C_DirsList::load(const C_Path& path, QListView* list_dirs, QListViewItem* r
         // note full path is set in each case later
         full_path.SetName(curr);
 
-        if (root == NULL) {
-            full_path.SetPath(path.FullPath());
+		full_path.SetPath(root->FullPath());
 
-            item = new C_DirViewItem(list_dirs, root_item);
-		}
-		else {
-            full_path.SetPath(root->text(EsvnLVI::ITEM_FULL_PATH));
+		item = new C_DirViewItem(root);
 
-            item = new C_DirViewItem(root);
-			root->setOpen(open);
-			root->setPixmap(0, getIcon(full_path.FullPath(), open, &svn_file_info) );
+		root->setOpen(open);
+		root->setPixmap(0, getIcon(root->FullPath(), open, &svn_file_info) );
 
 
-			if (hasSubDirs(full_path.FullPath(), disable_symlinks)) {
-				C_DirViewItem *sub_item = new C_DirViewItem(item);
-                sub_item->SetPath("empty item");
-			}
+		if (hasSubDirs(full_path.FullPath(), disable_symlinks)) {
+			C_DirViewItem *sub_item = new C_DirViewItem(item);
+			sub_item->SetPath("empty item");
 		}
 
         item->SetPath(full_path.Path());
         item->SetName(full_path.Name());
 
-		item->setPixmap(0, getIcon(item->FullPath(), false, &svn_file_info) );
-	}
+        item->setPixmap(0, getIcon(item->FullPath(), false, &svn_file_info) );
+    }
 
 
-	return true;
+    return true;
 }
 
 QPixmap C_DirsList::getIcon(const QString& dir_name, bool is_open,  C_SvnFile *svn_file_info)
 {
 
-	//cout << "dir:" << dir_name << endl; 
-	QPixmap result = QPixmap::fromMimeSource("folder_green.png");;
+    //cout << "dir:" << dir_name << endl; 
+    QPixmap result = QPixmap::fromMimeSource("folder_green.png");;
 
-	if (isSvnControlled(dir_name)) {
-		if (is_open) 
-			result = QPixmap::fromMimeSource("folder_green_open.png");
-		else		 
-			result = QPixmap::fromMimeSource("folder_green.png");
-	}
-	else {
-		if (is_open) 
-			result = QPixmap::fromMimeSource("folder_grey_open.png");
-		else		 
-			result = QPixmap::fromMimeSource("folder_grey.png");
-	}
+    if (isSvnControlled(dir_name)) {
+        if (is_open) 
+            result = QPixmap::fromMimeSource("folder_green_open.png");
+        else         
+            result = QPixmap::fromMimeSource("folder_green.png");
+    }
+    else {
+        if (is_open) 
+            result = QPixmap::fromMimeSource("folder_grey_open.png");
+        else         
+            result = QPixmap::fromMimeSource("folder_grey.png");
+    }
 
-	if (!svn_status_ || !svn_file_info) 	//if revision's testing disbale 
-		return result;
+    if (!svn_status_ || !svn_file_info)     //if revision's testing disabled
+        return result;
 
-	//revision list defined (fully colorized)
-	if (isSvnControlled(dir_name)) {
+    //revision list defined (fully colorized)
+    if (isSvnControlled(dir_name)) {
 
-		if (svn_file_info->modif_dtm_ == svn_file_info->text_dtm_) {
-			QString full_name = svn_file_info->name_;
-			if (!dir_name.isEmpty()) 
-				full_name = dir_name ;//+ "/" + svn_file_info->name_;
-			//cout << "full name: " << full_name << " " << svn_file_info->name_ << endl;
-				
-			if (svn_status_->getData()->find(full_name) != svn_status_->getData()->end()) {
-				if (svn_status_->getData()->find(full_name)->second.last_ch_rev_ != svn_file_info->commited_revision_) {
-					result = QPixmap::fromMimeSource("folder_exec_3.png");
-					// cout << "out-of-date : " << rev_list_->find(full_name)->second  << " " << svn_file_info->commited_revision_ << endl;
-					return result;
-				}
-			}
-		}
-		else {
-			result = QPixmap::fromMimeSource( "folder_red.png"); //modified
-			//cout << "modified" << endl;
-		}
+        if (svn_file_info->modif_dtm_ == svn_file_info->text_dtm_) {
+            QString full_name = svn_file_info->name_;
+            if (!dir_name.isEmpty()) 
+                full_name = dir_name ;//+ "/" + svn_file_info->name_;
+            //cout << "full name: " << full_name << " " << svn_file_info->name_ << endl;
+                
+            if (svn_status_->getData()->find(full_name) != svn_status_->getData()->end()) {
+                if (svn_status_->getData()->find(full_name)->second.last_ch_rev_ != svn_file_info->commited_revision_) {
+                    result = QPixmap::fromMimeSource("folder_exec_3.png");
+                    // cout << "out-of-date : " << rev_list_->find(full_name)->second  << " " << svn_file_info->commited_revision_ << endl;
+                    return result;
+                }
+            }
+        }
+        else {
+            result = QPixmap::fromMimeSource( "folder_red.png"); //modified
+            //cout << "modified" << endl;
+        }
 
-		if (svn_file_info->schedule_ == "add") 
-			result = QPixmap::fromMimeSource("folder_orange.png");
+        if (svn_file_info->schedule_ == "add") 
+            result = QPixmap::fromMimeSource("folder_orange.png");
 
-		if (svn_file_info->schedule_ == "delete") 
-			result = QPixmap::fromMimeSource( "folder_red_3.png");
-	}
-	//else
-		//cout << "non-svn" << endl;
+        if (svn_file_info->schedule_ == "delete") 
+            result = QPixmap::fromMimeSource( "folder_red_3.png");
+    }
+    //else
+        //cout << "non-svn" << endl;
 
 
-	return result;
+    return result;
 }
 
 
@@ -194,30 +180,30 @@ bool C_FilesList::load_real(const QString& rel_path_prefix, const C_Path& base_p
 
     QDir files =  QDir(path.FullPath());
 
-	files.setFilter(QDir::Files | QDir::Hidden | QDir::Dirs );
+    files.setFilter(QDir::Files | QDir::Hidden | QDir::Dirs );
 
-	if (!files.exists() ) {
-		qWarning( ("Cannot find the " + path.FullPath()).local8Bit());
-		return false;
-	}
+    if (!files.exists() ) {
+        qWarning( ("Cannot find the " + path.FullPath()).local8Bit());
+        return false;
+    }
 
-	C_SvnEntries curr_svn_entries;
-	curr_svn_entries.setSvnDir(svn_dir_);
+    C_SvnEntries curr_svn_entries;
+    curr_svn_entries.setSvnDir(svn_dir_);
     curr_svn_entries.setDir(path, show_dirs);
 
-	for (size_t i=0; i<files.count(); i++) {
+    for (size_t i=0; i<files.count(); i++) {
 
-		QString curr = files[i];
-		if (curr == "." || curr == ".." || curr == svn_dir_) 
-			continue;
+        QString curr = files[i];
+        if (curr == "." || curr == ".." || curr == svn_dir_) 
+            continue;
 
-		C_SvnFile svn_file_info = curr_svn_entries.get(curr);
+        C_SvnFile svn_file_info = curr_svn_entries.get(curr);
 
-		if (!svn_file_info.is_svn_controled_ && hide_unknown) 
-			continue;
+        if (!svn_file_info.is_svn_controled_ && hide_unknown) 
+            continue;
 
         // Remove name from current entries to catch objects missing from this directory later
-		curr_svn_entries.erase(curr);
+        curr_svn_entries.erase(curr);
 
 
         QString curr_rel_path = C_Path::Concat(rel_path_prefix, curr);
@@ -230,7 +216,7 @@ bool C_FilesList::load_real(const QString& rel_path_prefix, const C_Path& base_p
                     C_RelativePath full_name(path, svn_file_info.name_);
 
                     //if (svn_status && svn_status->getData()->find(full_name) != svn_status->getData()->end() ) {
-                    //	cout <<"LIST: " << full_name << " " << svn_status->getData()->find(full_name)->second.status_  << endl;
+                    //  cout <<"LIST: " << full_name << " " << svn_status->getData()->find(full_name)->second.status_  << endl;
                     //}
 
                     if (svn_status && svn_status->getData()->find(full_name.FullPath()) != svn_status->getData()->end()
@@ -238,7 +224,7 @@ bool C_FilesList::load_real(const QString& rel_path_prefix, const C_Path& base_p
 
                         //cout << full_name << " " << svn_status->getData()->find(full_name)->second.last_ch_rev_ << " : " << svn_file_info.commited_revision_ << endl;
 
-                        if (svn_file_info.kind_ == QString("dir") ) {				
+                        if (svn_file_info.kind_ == QString("dir") ) {               
                             item->setPixmap(0, QPixmap::fromMimeSource( "folder_exec_3.png")) ;
                             item->SetIsDir(true);
                         } 
@@ -248,7 +234,7 @@ bool C_FilesList::load_real(const QString& rel_path_prefix, const C_Path& base_p
                         item->setText(1, "out-of-date");
                     }
                     else {
-                        if (svn_file_info.kind_ == QString("dir") ) {				
+                        if (svn_file_info.kind_ == QString("dir") ) {               
                             item->setPixmap(0, QPixmap::fromMimeSource( "folder_green.png")) ;
                             item->SetIsDir(true);
                         } 
@@ -259,19 +245,19 @@ bool C_FilesList::load_real(const QString& rel_path_prefix, const C_Path& base_p
                     }
                 }
                 else {
-                    if (svn_file_info.kind_ == QString("dir") ) {				
+                    if (svn_file_info.kind_ == QString("dir") ) {               
                         item->setPixmap(0, QPixmap::fromMimeSource( "folder_red.png")) ;
                         item->SetIsDir(true);
                     } 
                     else 
                         item->setPixmap(0, QPixmap::fromMimeSource( "FileModified16x16.xpm" ) );
 
-					//cout << "modified" << endl;
-					item->setText(1, "modified");
+                    //cout << "modified" << endl;
+                    item->setText(1, "modified");
                 }
 
                 if (svn_file_info.schedule_ == "add") {
-                    if (svn_file_info.kind_ == QString("dir") ) {				
+                    if (svn_file_info.kind_ == QString("dir") ) {               
                         item->setPixmap(0, QPixmap::fromMimeSource( "folder_orange.png")) ;
                         item->SetIsDir(true);
                     } 
@@ -283,7 +269,7 @@ bool C_FilesList::load_real(const QString& rel_path_prefix, const C_Path& base_p
 
 
                 if (svn_file_info.schedule_ == "delete") {
-                    if (svn_file_info.kind_ == QString("dir") ) {				
+                    if (svn_file_info.kind_ == QString("dir") ) {               
                         item->setPixmap(0, QPixmap::fromMimeSource( "folder_red_3.png")) ;
                         item->SetIsDir(true);
                     }
@@ -298,17 +284,17 @@ bool C_FilesList::load_real(const QString& rel_path_prefix, const C_Path& base_p
                     item->setText(1, "conflict");
                 }
 
-				if (svn_file_info.is_symlink_) {
-					item->setPixmap(0, QPixmap::fromMimeSource( "FileLocked16x16.xpm" ) );
-					item->setText(1, "symlink");
-				}
+                if (svn_file_info.is_symlink_) {
+                    item->setPixmap(0, QPixmap::fromMimeSource( "FileLocked16x16.xpm" ) );
+                    item->setText(1, "symlink");
+                }
 
                 item->setText(2, svn_file_info.revision_);
                 item->setText(3, svn_file_info.commited_revision_);
-                item->setText(4, EsvnUtils::UTC2Local(svn_file_info.commited_dtm_).toString("yy/MM/dd hh:mm:ss"));
+                item->setText(4, svn_file_info.commited_dtm_.toString("yy/MM/dd hh:mm:ss"));
 
                 if (svn_file_info.modif_dtm_.isValid() )
-                    item->setText(5, EsvnUtils::UTC2Local(svn_file_info.modif_dtm_).toString("yy/MM/dd hh:mm:ss"));
+                    item->setText(5, svn_file_info.modif_dtm_.toString("yy/MM/dd hh:mm:ss"));
 
                 item->setText(6, svn_file_info.last_author_);
 
@@ -345,55 +331,55 @@ bool C_FilesList::load_real(const QString& rel_path_prefix, const C_Path& base_p
         } else {
             // simple fallthrough allows to skip descending to unknown dirs
         }
-	}
+    }
 
-	//cout << "rest:" << curr_svn_entries.getData().size() << endl;;
+    //cout << "rest:" << curr_svn_entries.getData().size() << endl;;
 
-	Name2SvnFileMap::iterator iter_entries;
-	for (iter_entries = curr_svn_entries.getData().begin(); iter_entries != curr_svn_entries.getData().end(); ++iter_entries) {
-		C_SvnFile svn_file_info = iter_entries->second;
+    Name2SvnFileMap::iterator iter_entries;
+    for (iter_entries = curr_svn_entries.getData().begin(); iter_entries != curr_svn_entries.getData().end(); ++iter_entries) {
+        C_SvnFile svn_file_info = iter_entries->second;
 
-		if (!show_dirs && svn_file_info.kind_ != "file") 
-			continue;
+        if (!show_dirs && svn_file_info.kind_ != "file") 
+            continue;
 
-		if (!svn_file_info.is_svn_controled_ || svn_file_info.name_ == "" || svn_file_info.name_ == "." || svn_file_info.name_ == ".."  || svn_file_info.name_ == svn_dir_  || /*svn_file_info.kind_ != "file" ||*/ svn_file_info.deleted_ == "true") 
-			continue;
+        if (!svn_file_info.is_svn_controled_ || svn_file_info.name_ == "" || svn_file_info.name_ == "." || svn_file_info.name_ == ".."  || svn_file_info.name_ == svn_dir_  || /*svn_file_info.kind_ != "file" ||*/ svn_file_info.deleted_ == "true") 
+            continue;
 
 
         QString curr_rel_path = C_Path::Concat(rel_path_prefix, svn_file_info.name_);
-		C_NumSortedFileListItem* item = new C_NumSortedFileListItem(base_path, curr_rel_path, list_files, 0);
+        C_NumSortedFileListItem* item = new C_NumSortedFileListItem(base_path, curr_rel_path, list_files, 0);
 
-		if (svn_file_info.schedule_ == "delete") {
-			if (svn_file_info.kind_ == QString("dir") ) {				
-				item->setPixmap(0, QPixmap::fromMimeSource( "folder_orange.png")) ;
-				item->SetIsDir(true);
-			}
-			else
-				item->setPixmap(0, QPixmap::fromMimeSource( "FileRemoved16x16.xpm" ) );
+        if (svn_file_info.schedule_ == "delete") {
+            if (svn_file_info.kind_ == QString("dir") ) {               
+                item->setPixmap(0, QPixmap::fromMimeSource( "folder_orange.png")) ;
+                item->SetIsDir(true);
+            }
+            else
+                item->setPixmap(0, QPixmap::fromMimeSource( "FileRemoved16x16.xpm" ) );
 
-			item->setText(1, "removed");
-		}
-		else {
-			if (svn_file_info.is_svn_controled_) {
-				if (svn_file_info.kind_ == QString("dir") ) {				
-					item->setPixmap(0, QPixmap::fromMimeSource( "folder_violet.png")) ;
-					item->SetIsDir(true);
-				}
-				else
-					item->setPixmap(0, QPixmap::fromMimeSource( "FileNeedsCheckout16x16.xpm" ) );
-				item->setText(1, "missing");
-			}
-		}
+            item->setText(1, "removed");
+        }
+        else {
+            if (svn_file_info.is_svn_controled_) {
+                if (svn_file_info.kind_ == QString("dir") ) {               
+                    item->setPixmap(0, QPixmap::fromMimeSource( "folder_violet.png")) ;
+                    item->SetIsDir(true);
+                }
+                else
+                    item->setPixmap(0, QPixmap::fromMimeSource( "FileNeedsCheckout16x16.xpm" ) );
+                item->setText(1, "missing");
+            }
+        }
 
-		item->setText(2, svn_file_info.revision_);
-		item->setText(3, svn_file_info.commited_revision_);
+        item->setText(2, svn_file_info.revision_);
+        item->setText(3, svn_file_info.commited_revision_);
 
-		item->setText(4, EsvnUtils::UTC2Local(svn_file_info.commited_dtm_).toString("yy/MM/dd hh:mm:ss"));
+        item->setText(4, svn_file_info.commited_dtm_.toString("yy/MM/dd hh:mm:ss"));
 
-		if (svn_file_info.modif_dtm_.isValid())
-			item->setText(5, EsvnUtils::UTC2Local(svn_file_info.modif_dtm_).toString("yy/MM/dd hh:mm:ss"));
+        if (svn_file_info.modif_dtm_.isValid())
+            item->setText(5, svn_file_info.modif_dtm_.toString("yy/MM/dd hh:mm:ss"));
 
-		item->setText(6, svn_file_info.last_author_);
+        item->setText(6, svn_file_info.last_author_);
 
         // allow descend to subdirs
         if (flat_view && svn_file_info.kind_ == QString("dir") ) {
@@ -402,8 +388,8 @@ bool C_FilesList::load_real(const QString& rel_path_prefix, const C_Path& base_p
             // simple fallthrough allows to skip descending to unknown dirs
         }
 
-	}
-	return true;
+    }
+    return true;
 }
 
 C_DirViewItem::C_DirViewItem(QListView *parent, QListViewItem *after)
