@@ -18,13 +18,13 @@
 #include "commitwindow.h"
 #include "esvn_utils.h"
 
-C_MainWindow::C_MainWindow(QWidget* parent , const char* name ) 
+C_MainWindow::C_MainWindow(QWidget* parent , const char* name )
 : frm_main(parent, name), hide_unknown_(true), show_flat_view_(false), show_changed_items_only_(false)
 {
 	in_timer_now_ = false;
 
-	QString version = (char*)VERSION;
-	setCaption(caption() + " " + version);
+	baseCaption_ = QString(caption() + " " + (char*)VERSION).stripWhiteSpace();
+	setCaption(baseCaption_);
 
 	setPopupMenu();
 	diff_tmp_file_ = "";
@@ -32,7 +32,7 @@ C_MainWindow::C_MainWindow(QWidget* parent , const char* name )
 
 	for (int i = 0; i < MAX_RECENT_FILES; ++i)
 		recent_file_ids_[i] = -1;
-	
+
 	/* style for non resizable dlgs */
 	int dlg_Style = WStyle_Customize|WStyle_DialogBorder|WStyle_SysMenu|WStyle_Title|WStyle_ContextHelp;
 
@@ -55,7 +55,7 @@ C_MainWindow::C_MainWindow(QWidget* parent , const char* name )
 
 	dlg_about_      = new dlg_about(this);
 	dlg_options_    = new dlg_options(this, NULL, TRUE, dlg_Style);
-	dlg_checkout_   = new dlg_checkout(this, NULL, TRUE, dlg_Style); 
+	dlg_checkout_   = new dlg_checkout(this, NULL, TRUE, dlg_Style);
 	dlg_import_		= new dlg_import(this);
 	dlg_export_		= new dlg_export(this, NULL, TRUE, dlg_Style);
 	dlg_startup_ 	= new dlg_startup(this);
@@ -81,7 +81,7 @@ C_MainWindow::C_MainWindow(QWidget* parent , const char* name )
 	dlg_log_ = new C_LogWindow();
 	dlg_log_->setParams(svn_commands_, dlg_view_, dlg_diff_);
 
-	dlg_prop_ = new C_PropWindow(this); 
+	dlg_prop_ = new C_PropWindow(this);
 
 	dlg_repos_ = new C_ReposWindow(this);
 	dlg_repos_->setParams(svn_commands_, dlg_view_, dlg_checkout_);
@@ -137,49 +137,49 @@ C_MainWindow::~C_MainWindow() {
 void C_MainWindow::setPopupMenu() {
 	mnu_popup_ = new QPopupMenu;
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("update_16x16.xpm"), "Update      ",this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("update_16x16.xpm"), "Update      ",this,
 						   SLOT(modifyUpdateAction_activated()));
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("update_16x16.xpm"), "Update revision ...",this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("update_16x16.xpm"), "Update revision ...",this,
 						   SLOT(modifyUpdate_revision_Action_activated()));
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("commit_16x16.xpm"), "Commit ...",this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("commit_16x16.xpm"), "Commit ...",this,
 						   SLOT(modifyCommitAction_activated()));
 
 	mnu_popup_->insertSeparator();
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("edit.png"), "Edit",  this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("edit.png"), "Edit",  this,
 						   SLOT(modifyEditAction_activated()));
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("kdar.png"), "Properties ...",  this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("kdar.png"), "Properties ...",  this,
 						   SLOT(queryProperties_activated()));
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("module_add_16x16.xpm"),"Add", this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("module_add_16x16.xpm"),"Add", this,
 						   SLOT(modifyAddAction_activated()));
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("Delete16x16.xpm"),"Delete", this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("Delete16x16.xpm"),"Delete", this,
 						   SLOT(modifyDeleteAction_activated()));
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("revert.png"),"Revert", this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("revert.png"),"Revert", this,
 						   SLOT(modifyRevertAction_activated()));
 
 	mnu_popup_->insertSeparator();
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("ktip.png"), "Quick Diff",  this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("ktip.png"), "Quick Diff",  this,
 						   SLOT(queryQuick_DiffAction_activated()));
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("services.png"), "Diff ...",  this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("services.png"), "Diff ...",  this,
 						   SLOT(queryDiffAction_activated()));
 
 	mnu_popup_->insertSeparator();
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("merge_16x16.xpm"), "Merge ...",  this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("merge_16x16.xpm"), "Merge ...",  this,
 						   SLOT(modifyMegreAction_activated()));
 
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("backimage.png"),"Switch ...", this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("backimage.png"),"Switch ...", this,
 						   SLOT(modifySwitchAction_activated()));
 
 	mnu_popup_->insertSeparator();
-	mnu_popup_->insertItem(QPixmap::fromMimeSource("cvs_annotate_16x16.xpm"), "Info",  this, 
+	mnu_popup_->insertItem(QPixmap::fromMimeSource("cvs_annotate_16x16.xpm"), "Info",  this,
 						   SLOT(queryInfoAction_activated()));
 
 	mnu_popup_->insertItem(QPixmap::fromMimeSource("LogTree16x16.xpm"), "Log", this,
@@ -245,7 +245,7 @@ void C_MainWindow::loadWorkspace(const C_DirPath& path, QString name, bool appen
 
 	if (!dirs_list_->load(workspace_, list_dirs, NULL, true, dlg_options_->ch_disablesl->isChecked(), append)) {
 		workspace_ = old_workspace_dir;
-		QMessageBox::information(this, "Open failed", "Can't open workspace/directory"); 
+		QMessageBox::information(this, "Open failed", "Can't open workspace/directory");
 		dir_refresh_disable_ = false;
 		QApplication::restoreOverrideCursor();
 		list_dirs->blockSignals(false);
@@ -265,6 +265,9 @@ void C_MainWindow::loadWorkspace(const C_DirPath& path, QString name, bool appen
 
 	QApplication::restoreOverrideCursor();
 	list_dirs->blockSignals(false);
+
+	setCaption(workspace_.FullPath() + " - " + baseCaption_);
+
 }
 
 
@@ -291,14 +294,14 @@ void C_MainWindow::updateRecentFileItems() {
 	}
 }
 
-void C_MainWindow::openRecentFile(int param) 
+void C_MainWindow::openRecentFile(int param)
 {
 	QString recent_name = recent_files_[param];
 	int pos = recent_name.find(" [ws]");
 	if (pos == -1) {
         C_DirPath wsPath = QDir(recent_name);
 		loadWorkspace(wsPath);
-		QSettings settings_; 
+		QSettings settings_;
 		settings_.setPath("umputun.com", "esvn", QSettings::User);
 		settings_.beginGroup("/esvn");
 		settings_.writeEntry("/state/active_workspace", "");
@@ -315,7 +318,7 @@ void C_MainWindow::openRecentFile(int param)
 
 
 //----------------------------- SLOTS (events) -------------------------------
-void C_MainWindow::list_dirs_doubleClicked(QListViewItem *item) 
+void C_MainWindow::list_dirs_doubleClicked(QListViewItem *item)
 {
 	//cout << "dbl" << endl;
     C_DirPath dir;
@@ -354,7 +357,7 @@ void C_MainWindow::list_dirs_selectionChanged(QListViewItem *item) {
 
 
 
-void C_MainWindow::list_files_selectionChanged(QListViewItem *item) 
+void C_MainWindow::list_files_selectionChanged(QListViewItem *item)
 {
     const C_Path *sel_path = dynamic_cast<const C_Path*>(item);
     if (!sel_path) {
@@ -390,7 +393,7 @@ void C_MainWindow::list_files_doubleClicked( QListViewItem *view_item)
 
 			//colorizeDirsList(parent);
 
-			if (!parent->isOpen()) 
+			if (!parent->isOpen())
 				list_dirs_doubleClicked(parent);
 
 			QListViewItemIterator iter(parent, QListViewItemIterator::Visible);
@@ -429,14 +432,14 @@ void C_MainWindow::list_files_doubleClicked( QListViewItem *view_item)
 			for (size_t i=0; i<open_map_.size(); i++) {
 				QString str = open_map_[i];
 				QStringList ext_prog = QStringList::split("|", str);
-				if (ext_prog.size() < 2) 
+				if (ext_prog.size() < 2)
 					continue;
 				QStringList exts = QStringList::split(",", ext_prog[0]);
 				for (size_t j=0; j<exts.size(); j++) {
 					if (exts[j] == fi.extension() ) {
 						QProcess proc;
                         proc.setWorkingDirectory(item->Path());
-						proc.addArgument(ext_prog[1]); 
+						proc.addArgument(ext_prog[1]);
 						proc.addArgument(item->Name());
 						textBrowser->append(ext_prog[1] + " " + item->Name());
 						proc.start();
@@ -470,7 +473,7 @@ void C_MainWindow::colorizeDirsList(QListViewItem *dir_item)
 }
 
 
-void C_MainWindow::modifyUpdateAction_activated() 
+void C_MainWindow::modifyUpdateAction_activated()
 {
 	sendToOutput("update");
 
@@ -515,7 +518,7 @@ void C_MainWindow::modifyUpdate_revision_Action_activated() {
 }
 
 
-void C_MainWindow::modifyRevertAction_activated() 
+void C_MainWindow::modifyRevertAction_activated()
 {
 	revert(false);
 }
@@ -537,7 +540,7 @@ void C_MainWindow::revert(bool is_recursive)
     }
 
     QString text_string ="You are about to revert the following items:\n\n";
-    for (size_t i=0; i< selection.size(); i++) 
+    for (size_t i=0; i< selection.size(); i++)
         text_string = text_string + selection[i].Name() + "\n";
 
     QMessageBox mb( "Confirmation",text_string,
@@ -581,13 +584,13 @@ void C_MainWindow::modifyCommitAction_activated() {
     //QListViewItem* item = EsvnLVI::getFirstSelectedItem(current_view);
     const C_DirPath *sel_path = dynamic_cast<C_DirPath*>(EsvnLVI::getFirstSelectedItem(list_dirs));
     if (!sel_path) {
-		QMessageBox::information(this, "Commit rejected", "No directory selection available"); 
+		QMessageBox::information(this, "Commit rejected", "No directory selection available");
         return;
     }
     QString currwd = sel_path->FullPath();
 
 	if (dlg_options_->ch_disable_cotag->isChecked() && getUrlOnline(*sel_path).find("/tags/") != -1) {
-		QMessageBox::information(this, "Commit rejected", "Can't commit to tag"); 
+		QMessageBox::information(this, "Commit rejected", "Can't commit to tag");
 		return;
 	}
 
@@ -628,7 +631,7 @@ void C_MainWindow::modifyEditAction_activated()
     // Get list of all selected paths
     PathSelection selection;
     if (!getSelectedFiles(selection)) {
-        QMessageBox::information(this, "Edit action rejected", "No selection"); 
+        QMessageBox::information(this, "Edit action rejected", "No selection");
         return;
     }
 
@@ -649,7 +652,7 @@ void C_MainWindow::modifyEditAction_activated()
 void C_MainWindow::modifyCleanupAction_activated() {
     PathSelection selection;
     if (!getSelectedPaths(selection)) {
-        QMessageBox::information(this, "Cleanup action rejected", "No selection"); 
+        QMessageBox::information(this, "Cleanup action rejected", "No selection");
         return;
     }
 
@@ -709,7 +712,7 @@ void C_MainWindow::modifyDeleteAction_activated()
     svn_commands_->del(selection);
 }
 
-void C_MainWindow::modifyCopyAction_activated() 
+void C_MainWindow::modifyCopyAction_activated()
 {
     // current working directory is stored in dlg_copy_->lb_url
 
@@ -724,12 +727,12 @@ void C_MainWindow::modifyCopyAction_activated()
 
         QString currwd = dlg_copy_->lb_url->text();
 
-        for (size_t i=0; i<files.size(); i++) 
-			svn_commands_->copy(currwd, files[i], dlg_copy_->le_dest->text(), dlg_copy_->te_msg->text(), rev); 
+        for (size_t i=0; i<files.size(); i++)
+			svn_commands_->copy(currwd, files[i], dlg_copy_->le_dest->text(), dlg_copy_->te_msg->text(), rev);
 	}
 }
 
-void C_MainWindow::modifyCopy_remote_Action_activated() 
+void C_MainWindow::modifyCopy_remote_Action_activated()
 {
     PathSelection selection;
 
@@ -751,7 +754,7 @@ void C_MainWindow::modifyCopy_remote_Action_activated()
     for (size_t i=0; i<selection.size(); i++) {
         QString url = getUrlOnline(selection[i]);
         sel_names = sel_names + url;
-        if (i != selection.size()-1) 
+        if (i != selection.size()-1)
             sel_names = sel_names + ';';
     }
 	dlg_copy_->le_source->setText(sel_names);
@@ -781,7 +784,7 @@ void C_MainWindow::modifyCopy_current_Action_activated()
     QString sel_names;
     for (size_t i=0; i<selection.size(); i++) {
         sel_names = sel_names + selection[i].Name();
-        if (i != selection.size()-1) 
+        if (i != selection.size()-1)
             sel_names = sel_names + ';';
     }
     dlg_copy_->le_source->setText(sel_names);
@@ -789,7 +792,7 @@ void C_MainWindow::modifyCopy_current_Action_activated()
 	modifyCopyAction_activated();
 }
 
-void C_MainWindow::modifyMoveAction_activated() 
+void C_MainWindow::modifyMoveAction_activated()
 {
     PathSelection selection;
 
@@ -810,7 +813,7 @@ void C_MainWindow::modifyMoveAction_activated()
     QString sel_names;
     for (size_t i=0; i<selection.size(); i++) {
         sel_names = sel_names + selection[i].Name();
-        if (i != selection.size()-1) 
+        if (i != selection.size()-1)
             sel_names = sel_names + ';';
     }
     dlg_copy_->le_source->setText(sel_names);
@@ -824,8 +827,8 @@ void C_MainWindow::modifyMoveAction_activated()
 
 		QStringList files = QStringList::split(';', dlg_copy_->le_source->text());
 
-		for (size_t i=0; i<files.size(); i++) 
-			svn_commands_->move(selection[0].Path(), files[i], dlg_copy_->le_dest->text(),dlg_copy_->te_msg->text(), rev); 
+		for (size_t i=0; i<files.size(); i++)
+			svn_commands_->move(selection[0].Path(), files[i], dlg_copy_->le_dest->text(),dlg_copy_->te_msg->text(), rev);
 	}
 }
 
@@ -851,12 +854,12 @@ void C_MainWindow::modifySwitchAction_activated() {
 		else
 			rev	= "{" + dlg_switch_->le_date->text() + "}";
 
-		svn_commands_->switch_cmd(*path, dlg_switch_->le_url->text(), rev, dlg_switch_->ch_recur->isChecked()); 
+		svn_commands_->switch_cmd(*path, dlg_switch_->le_url->text(), rev, dlg_switch_->ch_recur->isChecked());
 	}
 }
 
 
-void C_MainWindow::modifyMegreAction_activated() 
+void C_MainWindow::modifyMegreAction_activated()
 {
     // Get current view
     QListView* current_view = is_selected_dir_?list_dirs:list_files;
@@ -900,8 +903,8 @@ void C_MainWindow::modifyMegreAction_activated()
         svn_commands_->merge(sel_path->Path(),
                              file_url, first, second, wcpath,
 							 dlg_merge_->rb_revision->isChecked(),
-							 dlg_merge_->ch_nonrecursive->isChecked(), 
-							 dlg_merge_->ch_dryrun->isChecked()); 
+							 dlg_merge_->ch_nonrecursive->isChecked(),
+							 dlg_merge_->ch_dryrun->isChecked());
 	}
 }
 
@@ -920,7 +923,7 @@ void C_MainWindow::modifyMake_directory_Action_activated()
             "Enter directory name:", QLineEdit::Normal,
             QString::null, &ok, this );
 
-	if ( ok && !text.isEmpty() ) 
+	if ( ok && !text.isEmpty() )
 		svn_commands_->mkdir(sel_path->FullPath(), text);
 }
 
@@ -995,12 +998,12 @@ void C_MainWindow::refreshList()
 	auto_refresh_disable_ = false;
 }
 
-void C_MainWindow::viewRefresh_localAction_activated() 
+void C_MainWindow::viewRefresh_localAction_activated()
 {
 	QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
 
 	time(&last_refresh_);
-	if (dlg_options_->rb_online->isChecked()) 
+	if (dlg_options_->rb_online->isChecked())
 		fillSvnStatus(svn_status_);
 
 
@@ -1025,14 +1028,14 @@ void C_MainWindow::viewHide_unknownAction_toggled(bool hide) {
 	viewRefresh_localAction_activated();
 }
 
-void C_MainWindow::viewRefresh_workspaceAction_activated() 
+void C_MainWindow::viewRefresh_workspaceAction_activated()
 {
 
-	QSettings settings_; 
+	QSettings settings_;
 	settings_.setPath("umputun.com", "esvn", QSettings::User);
 	settings_.beginGroup("/esvn");
 
-	QString ws_name = settings_.readEntry("/state/active_workspace", ""); 
+	QString ws_name = settings_.readEntry("/state/active_workspace", "");
 	if (ws_name.isEmpty()) {
 		loadWorkspace(workspace_);
 	}
@@ -1078,7 +1081,7 @@ void C_MainWindow::show_Log(const C_Path& pathname)
     show_Log(pathname, show_changed_paths);
 }
 
-void C_MainWindow::queryLogAction_activated() 
+void C_MainWindow::queryLogAction_activated()
 {
     // Get current view
     QListView* current_view = is_selected_dir_?list_dirs:list_files;
@@ -1115,7 +1118,7 @@ void C_MainWindow::show_View(const C_Path& pathname)
 	if (res == 0) {
 		dlg_view_->tb_view->clear();
 		for (size_t i=0; i<cat.size(); i++) {
-			if (cat[i].isEmpty()) 
+			if (cat[i].isEmpty())
 				dlg_view_->tb_view->append(" ");
 			else
 				dlg_view_->tb_view->append(cat[i]);
@@ -1208,7 +1211,7 @@ void C_MainWindow::queryInfoAction_activated()
 }
 
 
-void C_MainWindow::queryDiffAction_activated() 
+void C_MainWindow::queryDiffAction_activated()
 {
     PathSelection selection;
 
@@ -1240,13 +1243,13 @@ void C_MainWindow::queryDiffAction_activated()
             QString first = dlg_diff_setup_->le_url1->text();
 
 
-            if (first.isEmpty()) 
+            if (first.isEmpty())
                 first = current.Name();
 
 
             if (!dlg_diff_setup_->ch_extdiff->isChecked())
                 internalDiff(current.Path(),
-                    first, dlg_diff_setup_->le_url2->text(), rev, 
+                    first, dlg_diff_setup_->le_url2->text(), rev,
                     dlg_diff_setup_->ch_nonrecursive->isChecked(), dlg_diff_setup_->ch_noticea->isChecked(),
                     dlg_diff_setup_->le_ext->text());
             else {
@@ -1334,7 +1337,7 @@ void C_MainWindow::query3_Way_DiffAction_activated()
 
 
 
-void C_MainWindow::queryQuick_DiffAction_activated() 
+void C_MainWindow::queryQuick_DiffAction_activated()
 {
     // Get current view
     QListView* current_view = is_selected_dir_?list_dirs:list_files;
@@ -1360,13 +1363,13 @@ void C_MainWindow::queryQuick_DiffAction_activated()
 }
 
 void C_MainWindow::internalDiff(const QString& currwd,
-    const QString& file_dir_name_1, const QString& file_dir_name_2, 
-	const QString& rev, bool non_recursive, bool notice_ancestry, 
+    const QString& file_dir_name_1, const QString& file_dir_name_2,
+	const QString& rev, bool non_recursive, bool notice_ancestry,
 	const QString& extensions)
 {
     QStringList diff_res;
 	int res = svn_commands_->diff(currwd,
-                                  file_dir_name_1, file_dir_name_2, rev, false, 
+                                  file_dir_name_1, file_dir_name_2, rev, false,
 								  non_recursive, notice_ancestry, extensions, diff_res);
 
 	if (res == 0) {
@@ -1397,7 +1400,7 @@ void C_MainWindow::internalDiff(const QString& currwd,
 }
 
 
-void C_MainWindow::queryProperties_activated() 
+void C_MainWindow::queryProperties_activated()
 {
     PathSelection selection;
 
@@ -1417,9 +1420,9 @@ void C_MainWindow::queryProperties_activated()
 
 
 
-void C_MainWindow::onTimer() 
+void C_MainWindow::onTimer()
 {
-	if (in_timer_now_) 
+	if (in_timer_now_)
 		return;
 
 	in_timer_now_ = true;
@@ -1452,7 +1455,7 @@ void C_MainWindow::onTimer()
 	}
 
 
-	//auto-refresh 
+	//auto-refresh
 	if (sel_path && !auto_refresh_disable_ && dlg_options_->sb_refresh->value() > 0 && dlg_options_->rb_online->isChecked()) {
 		time_t now;
 		time(&now);
@@ -1493,7 +1496,7 @@ void C_MainWindow::fileOpen_workspaceAction_activated() {
         C_DirPath wsPath = QDir(path);
 		loadWorkspace(wsPath);
 
-		QSettings settings_; 
+		QSettings settings_;
 		settings_.setPath("umputun.com", "esvn", QSettings::User);
 		settings_.beginGroup("/esvn");
 		settings_.writeEntry("/state/active_workspace", "");
@@ -1567,7 +1570,7 @@ void C_MainWindow::fileImport_Action_activated()
                               dlg_import_->le_url->text(), dlg_import_->le_path->text(),
 							  dlg_import_->te_msg->text(),
 							  dlg_import_->ch_nonrecursive->isChecked());
-		
+
 	}
 }
 
@@ -1593,19 +1596,19 @@ void C_MainWindow::fileWorkspaceAction_activated()
 	dlg_workspace_->fillWsInfo();
 	if (dlg_workspace_->exec() == QDialog::Accepted ) {
 		QListViewItem *sel_item = dlg_workspace_->lv_wslist->selectedItem();
-		if (sel_item && ws_.find(sel_item->text(0)) != ws_.end() ) 
+		if (sel_item && ws_.find(sel_item->text(0)) != ws_.end() )
 			loadWS(sel_item->text(0));
 	}
 }
 
 
-bool C_MainWindow::loadWS(const QString& ws_name) 
+bool C_MainWindow::loadWS(const QString& ws_name)
 {
 	QStringList dirs = ws_[ws_name];
-	
+
 	if (dirs.size() ==0)
 		return false;
-		
+
 	for (size_t i=0; i<dirs.size(); i++ ) {
         C_DirPath currDir = QDir(dirs[i]);
         dirs_list_->load(currDir, list_dirs, NULL, true, dlg_options_->ch_disablesl->isChecked(),  i>0 );
@@ -1613,7 +1616,7 @@ bool C_MainWindow::loadWS(const QString& ws_name)
 
 	list_dirs->setSelected(list_dirs->firstChild(), true);
 
-	QSettings settings_; 
+	QSettings settings_;
 	settings_.setPath("umputun.com", "esvn", QSettings::User);
 	settings_.beginGroup("/esvn");
 	settings_.writeEntry("/state/active_workspace", ws_name);
@@ -1625,9 +1628,11 @@ bool C_MainWindow::loadWS(const QString& ws_name)
 
 	updateRecentFileItems();
 	viewRefresh_localAction_activated();
-	
+
+	setCaption(ws_name + " - " + baseCaption_);
+
 	return true;
-}	
+}
 
 void C_MainWindow::fileShow_changed_filedirectoriesAction_activated()
 {
@@ -1646,12 +1651,12 @@ void C_MainWindow::fileShow_changed_filedirectoriesAction_activated()
 
 	if (dlg_changed_->exec() == QDialog::Accepted) {
 		QString selected_text = dlg_changed_->lv_status->currentItem()->text(0);
-		
+
 		//search changed item in dir panel
 		QListViewItem *parent = list_dirs->currentItem();
 		if (parent) {
 
-			if (!parent->isOpen()) 
+			if (!parent->isOpen())
 				list_dirs_doubleClicked(parent);
 
 			QListViewItem *curr_item = parent->firstChild();
@@ -1690,21 +1695,21 @@ void C_MainWindow::helpWebsiteAction_activated()
 {
 	QProcess process(this);
 	process.addArgument(dlg_options_->le_browser->text());
-	process.addArgument("http://esvn.umputun.com");
+	process.addArgument("http://zoneit.free.fr");
 	process.start();
 }
 
 void C_MainWindow::helpCheck_for_updatesAction_activated()
 {
-	http_.setHost("esvn.umputun.com");
-	http_.get("/update.shtml");
+	http_.setHost("zoneit.free.fr");
+	http_.get("/esvn/update.shtml");
 }
 
 void C_MainWindow::httpDone(bool error)
 {
 	if (error) {
-		QMessageBox::warning(this, "HTTP request", 
-			tr("Error while fetching update.html: %1") .arg(http_.errorString()) );
+		QMessageBox::warning(this, "HTTP request",
+			tr("Error while fetching update.shtml: %1") .arg(http_.errorString()) );
 		return;
 	}
 
@@ -1712,7 +1717,7 @@ void C_MainWindow::httpDone(bool error)
 	//textBrowser->append(response);
 	QStringList elems = QStringList::split(";", response);
 	if (elems.count() < 4 ) {
-		QMessageBox::warning(this, "Update", 
+		QMessageBox::warning(this, "Update",
 			"Wrong response: \n\n" + response);
 	}
 	else {
@@ -1744,13 +1749,13 @@ void C_MainWindow::httpDone(bool error)
 QStringList C_MainWindow::split(QString &str, char sep, bool is_trim)
 {
     QStringList result;
-                                                                                                                
+
     size_t separator_pos =0;
     while(separator_pos < str.length()) {
         int p = str.find(sep, separator_pos);
         if (p == -1)
             p = str.length();
-                                                                                                                
+
         QString elem = str.mid(separator_pos, p-separator_pos); //exctract element
         if(is_trim) {
             rtrim(elem);
@@ -1760,7 +1765,7 @@ QStringList C_MainWindow::split(QString &str, char sep, bool is_trim)
         result.push_back(elem);
         if (p >= (int)str.length()) break;
     }
-                                                                                                                
+
     return result;
 }
 
@@ -1785,10 +1790,10 @@ void C_MainWindow::rtrim(QString& str) {
 }
 
 
-void C_MainWindow::saveSettings() 
+void C_MainWindow::saveSettings()
 {
 
-	QSettings settings_; 
+	QSettings settings_;
 
 	settings_.setPath("umputun.com", "esvn", QSettings::User);
 
@@ -1864,7 +1869,7 @@ void C_MainWindow::saveSettings()
 
 	QStringList ws_names;
 	map<QString, QStringList>::iterator iter_ws;
-	for (iter_ws = ws_.begin(); iter_ws != ws_.end(); iter_ws++) 
+	for (iter_ws = ws_.begin(); iter_ws != ws_.end(); iter_ws++)
 		ws_names.push_back(iter_ws->first);
 
 	settings_.writeEntry("/workspace/names", ws_names);
@@ -1879,7 +1884,7 @@ void C_MainWindow::saveSettings()
 	settings_.writeEntry("/recently/size", int(recent_files_.size()));
 	for (size_t r = 0; r < recent_files_.size(); ++r) {
 		char tmp[128];
-		sprintf(tmp, "/recently/%d", r);
+		sprintf(tmp, "/recently/%d", (int) r);
 		settings_.writeEntry(tmp, recent_files_[r]);
 	}
 
@@ -1915,10 +1920,10 @@ void C_MainWindow::saveSettings()
 	settings_.endGroup();
 }
 
-void C_MainWindow::loadSettings() 
+void C_MainWindow::loadSettings()
 {
 
-	QSettings settings_; 
+	QSettings settings_;
 	settings_.setPath("umputun.com", "esvn", QSettings::User);
 	settings_.beginGroup("/esvn");
 
@@ -2080,7 +2085,7 @@ void C_MainWindow::loadSettings()
 	//busy.show();
 
 
-	QString ws_name = settings_.readEntry("/state/active_workspace", ""); 
+	QString ws_name = settings_.readEntry("/state/active_workspace", "");
 	if (ws_name.isEmpty()) {
 		QString working_directory = settings_.readEntry("/working_directory", "");
 
@@ -2224,10 +2229,10 @@ int getSelection(PathSelection& selection, QListView& view)
 
     while ( iter.current() ) {
         //QString fname = EsvnLVI::getFullPath(iter.current());
-        //cout << "sel: " << fname <<  endl; 
+        //cout << "sel: " << fname <<  endl;
         const C_Path* path = dynamic_cast<const C_Path*>(iter.current());
         if (path) {
-            //cout << "sel dir: " << path->Path() << " name: " << path->Name() <<  endl; 
+            //cout << "sel dir: " << path->Path() << " name: " << path->Name() <<  endl;
             selection.push_back(*path);
         } else {
             cout << "Warning: no conversion from list view item to path object available" << endl;
@@ -2294,7 +2299,7 @@ void C_MainWindow::getFilesAndSize(const C_Path& path, vector<QString>& files_an
 	}
 }
 
-void C_MainWindow::showHideToolBars() 
+void C_MainWindow::showHideToolBars()
 {
 
 	if (viewToolbarsFileAction->isOn() ) 	tlb_file->show();
@@ -2337,7 +2342,7 @@ void C_MainWindow::setSvnDir(const QString& dir)
 
 void C_MainWindow::sendToOutput(const QString& str)
 {
-	if (C_Options::instance()->dlgOptions()->rb_log_verb->isChecked() ) 
+	if (C_Options::instance()->dlgOptions()->rb_log_verb->isChecked() )
 		textBrowser->append( QString("<font color=grey>") + str + QString("</font>") );
 }
 
